@@ -1,5 +1,5 @@
 import pandas as pd
-from mvnmm import MVNMixtureModel
+from .mvnmm import MVNMixtureModel
 
 def run_inference(cov_df, lineages, k_interval=[10,30], n_runs=2, steps=500, lr=0.005,
         p=0.01, convergence=True, covariance="diag", show_progr=True, 
